{
  config,
  lib,
  pkgs,
  modulesPath,
  ...
}: {
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  boot = {
    initrd = {
      availableKernelModules = ["xhci_pci" "uas" "sd_mod"];
      kernelModules = [];

      luks.devices."luks-0ebc7402-5f50-4549-a407-b1f859285102".device = "/dev/disk/by-uuid/0ebc7402-5f50-4549-a407-b1f859285102";
    };

    kernelModules = ["kvm-amd" "amdgpu"];
    extraModulePackages = [];
  };

  services.xserver.videoDrivers = ["amdgpu"];

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/6ae6ea01-72d5-4cee-a512-7aab551577a0";
      fsType = "ext4";
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/B471-B193";
      fsType = "vfat";
    };
  };

  swapDevices = [
    {device = "/dev/disk/by-uuid/5b3a6fa6-bdec-4bfb-914d-48d870776a53";}
  ];

  networking = {
    useDHCP = lib.mkDefault true;
    interfaces.enp1s0.useDHCP = lib.mkDefault true;
    interfaces.wlp3s0.useDHCP = lib.mkDefault true;
  };

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";

  hardware = {
    opengl = {
      driSupport = true;
      driSupport32Bit = true;
      extraPackages = with pkgs; [
        rocm-opencl-icd
        rocm-opencl-runtime
      ];
    };

    cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
  };

  systemd.tmpfiles.rules = [
    "L+    /opt/rocm/hip   -    -    -     -    ${pkgs.hip}"
  ];
}
